@@ -1,11 +1,10 @@
+# -*- coding: utf-8 -*-
 """ Core components """
-import datetime
-
 from boto.exception import JSONResponseError, BotoServerError
 
-from dynamic_dynamodb.calculators import table as calculators
+from dynamic_dynamodb import calculators
+from dynamic_dynamodb.aws import dynamodb
 from dynamic_dynamodb.core import circuit_breaker
-from dynamic_dynamodb.core import dynamodb
 from dynamic_dynamodb.statistics import table as table_stats
 from dynamic_dynamodb.log_handler import LOGGER as logger
 from dynamic_dynamodb.config_handler import get_table_option, get_global_option
@@ -39,7 +38,10 @@ def ensure_provisioning(table_name, key_name):
                     int(updated_read_units),
                     int(updated_write_units)))
             __update_throughput(
-                table_name, updated_read_units, updated_write_units, key_name)
+                table_name,
+                updated_read_units,
+                updated_write_units,
+                key_name)
         else:
             logger.info('{0} - No need to change provisioning'.format(
                 table_name))
@@ -149,13 +151,13 @@ def __ensure_provisioning_reads(table_name, key_name):
             updated_provisioning = calculators.increase_reads_in_percent(
                 updated_read_units,
                 increase_reads_with,
-                key_name,
+                get_table_option(key_name, 'max_provisioned_reads'),
                 table_name)
         else:
             updated_provisioning = calculators.increase_reads_in_units(
                 updated_read_units,
                 increase_reads_with,
-                key_name,
+                get_table_option(key_name, 'max_provisioned_reads'),
                 table_name)
 
         if updated_read_units != updated_provisioning:
@@ -169,13 +171,13 @@ def __ensure_provisioning_reads(table_name, key_name):
                 updated_provisioning = calculators.increase_reads_in_percent(
                     updated_read_units,
                     increase_reads_with,
-                    key_name,
+                    get_table_option(key_name, 'max_provisioned_reads'),
                     table_name)
             else:
                 updated_provisioning = calculators.increase_reads_in_units(
                     updated_read_units,
                     increase_reads_with,
-                    key_name,
+                    get_table_option(key_name, 'max_provisioned_reads'),
                     table_name)
 
             if updated_read_units != updated_provisioning:
@@ -188,13 +190,13 @@ def __ensure_provisioning_reads(table_name, key_name):
             updated_provisioning = calculators.decrease_reads_in_percent(
                 updated_read_units,
                 decrease_reads_with,
-                key_name,
+                get_table_option(key_name, 'min_provisioned_reads'),
                 table_name)
         else:
             updated_provisioning = calculators.decrease_reads_in_units(
                 updated_read_units,
                 decrease_reads_with,
-                key_name,
+                get_table_option(key_name, 'min_provisioned_reads'),
                 table_name)
 
         if updated_read_units != updated_provisioning:
@@ -270,13 +272,13 @@ def __ensure_provisioning_writes(table_name, key_name):
             updated_provisioning = calculators.increase_writes_in_percent(
                 updated_write_units,
                 increase_writes_with,
-                key_name,
+                get_table_option(key_name, 'max_provisioned_writes'),
                 table_name)
         else:
             updated_provisioning = calculators.increase_writes_in_units(
                 updated_write_units,
                 increase_writes_with,
-                key_name,
+                get_table_option(key_name, 'max_provisioned_reads'),
                 table_name)
 
         if updated_write_units != updated_provisioning:
@@ -290,13 +292,13 @@ def __ensure_provisioning_writes(table_name, key_name):
                 updated_provisioning = calculators.increase_writes_in_percent(
                     updated_write_units,
                     increase_writes_with,
-                    key_name,
+                    get_table_option(key_name, 'max_provisioned_writes'),
                     table_name)
             else:
                 updated_provisioning = calculators.increase_writes_in_units(
                     updated_write_units,
                     increase_writes_with,
-                    key_name,
+                    get_table_option(key_name, 'max_provisioned_reads'),
                     table_name)
 
             if updated_write_units != updated_provisioning:
@@ -309,13 +311,13 @@ def __ensure_provisioning_writes(table_name, key_name):
             updated_provisioning = calculators.decrease_writes_in_percent(
                 updated_write_units,
                 decrease_writes_with,
-                key_name,
+                get_table_option(key_name, 'min_provisioned_writes'),
                 table_name)
         else:
             updated_provisioning = calculators.decrease_writes_in_units(
                 updated_write_units,
                 decrease_writes_with,
-                key_name,
+                get_table_option(key_name, 'min_provisioned_reads'),
                 table_name)
 
         if updated_write_units != updated_provisioning:
@@ -333,37 +335,6 @@ def __ensure_provisioning_writes(table_name, key_name):
     return update_needed, int(updated_write_units)
 
 
-def __is_maintenance_window(table_name, maintenance_windows):
-    """ Checks that the current time is within the maintenance window
-
-    :type table_name: str
-    :param table_name: Name of the DynamoDB table
-    :type maintenance_windows: str
-    :param maintenance_windows: Example: '00:00-01:00,10:00-11:00'
-    :returns: bool -- True if within maintenance window
-    """
-    # Example string '00:00-01:00,10:00-11:00'
-    maintenance_window_list = []
-    for window in maintenance_windows.split(','):
-        try:
-            start, end = window.split('-', 1)
-        except ValueError:
-            logger.error(
-                '{0} - Malformatted maintenance window'.format(table_name))
-            return False
-
-        maintenance_window_list.append((start, end))
-
-    now = datetime.datetime.utcnow().strftime('%H%M')
-    for maintenance_window in maintenance_window_list:
-        start = ''.join(maintenance_window[0].split(':'))
-        end = ''.join(maintenance_window[1].split(':'))
-        if now >= start and now <= end:
-            return True
-
-    return False
-
-
 def __update_throughput(table_name, read_units, write_units, key_name):
     """ Update throughput on the DynamoDB table
 
@@ -382,20 +353,6 @@ def __update_throughput(table_name, read_units, write_units, key_name):
     except JSONResponseError:
         raise
 
-    # Check that we are in the right time frame
-    if get_table_option(key_name, 'maintenance_windows'):
-        if (not __is_maintenance_window(table_name, get_table_option(
-                key_name, 'maintenance_windows'))):
-
-            logger.warning(
-                '{0} - Current time is outside maintenance window'.format(
-                    table_name))
-            return
-        else:
-            logger.info(
-                '{0} - Current time is within maintenance window'.format(
-                    table_name))
-
     # Check table status
     try:
         table_status = dynamodb.get_table_status(table_name)
@@ -422,9 +379,8 @@ def __update_throughput(table_name, read_units, write_units, key_name):
             logger.info('{0} - No changes to perform'.format(table_name))
             return
 
-    if not get_global_option('dry_run'):
-        dynamodb.update_table_provisioning(
-            table_name,
-            key_name,
-            int(read_units),
-            int(write_units))
+    dynamodb.update_table_provisioning(
+        table_name,
+        key_name,
+        int(read_units),
+        int(write_units))
