@@ -65,6 +65,21 @@ if config_handler.get_logging_option('log_config_file'):
     logging.config.fileConfig(os.path.expanduser(
         config_handler.get_logging_option('log_config_file')))
 else:
+    # File handler
+    if config_handler.get_logging_option('log_file'):
+        log_file = os.path.expanduser(
+            config_handler.get_logging_option('log_file'))
+        LOG_CONFIG['handlers']['file'] = {
+            'level': 'DEBUG',
+            'class': 'logging.handlers.TimedRotatingFileHandler',
+            'formatter': 'standard',
+            'filename': log_file,
+            'when': 'midnight',
+            'backupCount': 5
+        }
+        LOG_CONFIG['loggers']['']['handlers'].append('file')
+        LOG_CONFIG['loggers']['dynamic-dynamodb']['handlers'].append('file')
+
     # Configure a custom log level
     if config_handler.get_logging_option('log_level'):
         LOG_CONFIG['handlers']['console']['level'] = \
@@ -79,22 +94,6 @@ else:
         if 'file' in LOG_CONFIG['handlers']:
             LOG_CONFIG['handlers']['file']['formatter'] = 'dry-run'
 
-    # File handler
-    if config_handler.get_logging_option('log_file'):
-        log_file = os.path.expanduser(
-            config_handler.get_logging_option('log_file'))
-        LOG_CONFIG['handlers']['file'] = {
-            'level': 'DEBUG',
-            'class': 'logging.handlers.TimedRotatingFileHandler',
-            'formatter': 'standard',
-            'filename': log_file,
-            'when': 'midnight',
-            'backupCount': 5
-        }
-        LOG_CONFIG['loggers']['']['handlers'].append('file')
-        LOG_CONFIG['loggers']['dynamic-dynamodb']['handlers'].append(
-            'file')
-
     dictconfig.dictConfig(LOG_CONFIG)
 
 LOGGER = logging.getLogger('dynamic-dynamodb')
